==> 1.0.4.tar.gz: lib/src/entities/caravana_entity.dart <==
import 'package:equatable/equatable.dart';
import 'package:cloud_firestore/cloud_firestore.dart';

class CaravanaEntity extends Equatable {
  final String uuid;
  final String idManejo;
  final String idCuig;
  final String idElec;
  final String tropaUuid;
  final String tropaNombre;
  final String corralUuid;
  final String corralNombre;
  final DateTime fechaAlta;
  final double pesoAlta;
  final DateTime fechaUltPeso;
  final double pesoUlt;
  final bool sexo;
  final int denticion;
  final String estado;
  final int diasEncierre;
  final String empresaUuid;
  final String origen;
  final String propietario;
  final String empresaNombre;
  final String categoriaUuid;
  final String categoriaNombre;
  final int puerta;
  final String tropaOrigen;
  final String corralOrigen;
  final String categoriaAnterior;
  final double gdpv;
  final DateTime fechaUltimoEncierre;

  CaravanaEntity(
      this.uuid,
      this.idManejo,
      this.idCuig,
      this.idElec,
      this.tropaUuid,
      this.tropaNombre,
      this.corralUuid,
      this.corralNombre,
      this.fechaAlta,
      this.pesoAlta,
      this.fechaUltPeso,
      this.pesoUlt,
      this.sexo,
      this.denticion,
      this.estado,
      this.diasEncierre,
      this.empresaUuid,
      this.origen,
      this.propietario,
      this.empresaNombre,
      this.categoriaUuid,
      this.categoriaNombre,
      this.puerta,
      this.tropaOrigen,
      this.corralOrigen,
      this.categoriaAnterior,
      this.gdpv,
      this.fechaUltimoEncierre);

  Map<String, Object> toJson() {
    return {
      'categoriaNombre': this.categoriaNombre,
      'categoriaUuid': this.categoriaUuid,
      'corralNombre': this.corralNombre,
      'corralUuid': this.corralUuid,
      'denticion': this.denticion,
      'diasEncierre': this.diasEncierre,
      'empresaNombre': this.empresaNombre,
      'empresaUuid': this.empresaUuid,
      'estado': this.estado,
      'fechaAlta': this.fechaAlta,
      'fechaUltPeso': this.fechaUltPeso,
      'idCuig': this.idCuig,
      'idElec': this.idElec,
      'idManejo': this.idManejo,
      'origen': this.origen,
      'propietario': this.propietario,
      'pesoAlta': this.pesoAlta,
      'pesoUlt': this.pesoUlt,
      'puerta': this.puerta,
      'sexo': this.sexo,
      'tropaNombre': this.tropaNombre,
      'tropaUuid': this.tropaUuid,
      'tropaOrigen': this.tropaOrigen,
      'corralOrigen': this.corralOrigen,
      'categoriaAnterior': this.categoriaAnterior,
      'gdpv': this.gdpv,
      'fechaUltimoEncierre': this.fechaUltimoEncierre
    };
  }

  Map<String, Object> toMap() {
    return {
      'uuid': this.uuid,
      'categoriaNombre': this.categoriaNombre,
      'categoriaUuid': this.categoriaUuid,
      'corralNombre': this.corralNombre,
      'corralUuid': this.corralUuid,
      'denticion': this.denticion,
      'diasEncierre': this.diasEncierre,
      'empresaNombre': this.empresaNombre,
      'empresaUuid': this.empresaUuid,
      'estado': this.estado,
      'fechaAlta': this.fechaAlta,
      'fechaUltPeso': this.fechaUltPeso,
      'idCuig': this.idCuig,
      'idElec': this.idElec,
      'idManejo': this.idManejo,
      'origen': this.origen,
      'propietario': this.propietario,
      'pesoAlta': this.pesoAlta,
      'pesoUlt': this.pesoUlt,
      'puerta': this.puerta,
      'sexo': this.sexo,
      'tropaNombre': this.tropaNombre,
      'tropaUuid': this.tropaUuid,
      'tropaOrigen': this.tropaOrigen,
      'corralOrigen': this.corralOrigen,
      'categoriaAnterior': this.categoriaAnterior,
      'gdpv': this.gdpv,
      'fechaUltimoEncierre': this.fechaUltimoEncierre
    };
  }

  CaravanaEntity.fromMap(Map<dynamic, dynamic> data)
      : uuid = data['uuid'],
        idManejo = data['idManejo'],
        idCuig = data['idCuig'],
        idElec = data['idElec'],
        tropaUuid = data['tropaUuid'],
        tropaNombre = data['tropaNombre'],
        corralUuid = data['corralUuid'],
        corralNombre = data['corralNombre'],
        fechaAlta = data['fechaAlta'].runtimeType == DateTime
            ? data['fechaAlta']
            : data['fechaAlta'].toDate(),
        pesoAlta = double.parse(data['pesoAlta'].toString()),
        fechaUltPeso = data['fechaUltPeso'].runtimeType == DateTime
            ? data['fechaUltPeso']
            : data['fechaUltPeso'].toDate(),
        pesoUlt = double.parse(data['pesoUlt'].toString()),
        sexo = data['sexo'],
        denticion = data['denticion'],
        estado = data['estado'],
        diasEncierre = data['diasEncierre'],
        empresaUuid = data['empresaUuid'],
        origen = data['origen'],
        propietario = data['propietario'],
        empresaNombre = data['empresaNombre'],
        categoriaUuid = data['categoriaUuid'],
        categoriaNombre = data['categoriaNombre'],
        puerta = data['puerta'],
        tropaOrigen = data['tropaOrigen'] ?? data['tropaUuid'],
        corralOrigen = data['corralOrigen'] ?? data['corralUuid'],
        categoriaAnterior = data['categoriaAnterior'] ?? data['categoriaUuid'],
        gdpv = data['gdpv'],
        fechaUltimoEncierre = data['fechaUltimoEncierre'];

  @override
  String toString() {
    return 'CaravanaEntity{uuid: $uuid, idManejo: $idManejo, idCuig: $idCuig, idElec: $idElec, tropaUuid: $tropaUuid, tropaNombre: $tropaNombre, corralUuid: $corralUuid, corralNombre: $corralNombre, fechaAlta: $fechaAlta, pesoAlta: $pesoAlta, fechaUltPeso: $fechaUltPeso, pesoUlt: $pesoUlt, sexo: $sexo, denticion: $denticion, estado: $estado, diasEncierre: $diasEncierre, empresaUuid: $empresaUuid, origen: $origen, propietario: $propietario, empresaNombre: $empresaNombre, categoriaUuid: $categoriaUuid, categoriaNombre: $categoriaNombre, puerta: $puerta, tropaOrigen: $tropaOrigen, corralOrigen: $corralOrigen, categoriaAnterior: $categoriaAnterior, gdpv: $gdpv, fechaUltimoEncierre: $fechaUltimoEncierre}';
  }

  CaravanaEntity.fromJson(Map<String, dynamic> data)
      : uuid = data['uuid'],
        idManejo = data['idManejo'],
        idCuig = data['idCuig'],
        idElec = data['idElec'],
        tropaUuid = data['tropaUuid'],
        tropaNombre = data['tropaNombre'],
        corralUuid = data['corralUuid'],
        corralNombre = data['corralNombre'],
        fechaAlta = data['fechaAlta'].toDate(),
        pesoAlta = double.parse(data['pesoAlta'].toString()),
        fechaUltPeso = data['fechaUltPeso'].toDate(),
        pesoUlt = double.parse(data['pesoUlt'].toString()),
        sexo = data['sexo'],
        denticion = data['denticion'],
        estado = data['estado'],
        diasEncierre = data['diasEncierre'],
        empresaUuid = data['empresaUuid'],
        origen = data['origen'],
        propietario = data['propietario'],
        empresaNombre = data['empresaNombre'],
        categoriaUuid = data['categoriaUuid'],
        categoriaNombre = data['categoriaNombre'],
        puerta = data['puerta'],
        tropaOrigen = data['tropaOrigen'],
        corralOrigen = data['corralOrigen'],
        categoriaAnterior = data['categoriaAnterior'],
        gdpv = data['gdpv'],
        fechaUltimoEncierre = data['fechaUltimoEncierre'];

  CaravanaEntity.fromSnapshot(DocumentSnapshot snapshot)
      : uuid = snapshot.documentID,
        idManejo = snapshot.data['idManejo'],
        idCuig = snapshot.data['idCuig'],
        idElec = snapshot.data['idElec'],
        tropaUuid = snapshot.data['tropaUuid'],
        tropaNombre = snapshot.data['tropaNombre'],
        corralUuid = snapshot.data['corralUuid'],
        corralNombre = snapshot.data['corralNombre'],
        fechaAlta = snapshot.data['fechaAlta'].toDate(),
        pesoAlta = double.parse(snapshot.data['pesoAlta'].toString()),
        fechaUltPeso = snapshot.data['fechaUltPeso'].toDate(),
        pesoUlt = double.parse(snapshot.data['pesoUlt'].toString()),
        sexo = snapshot.data['sexo'],
        denticion = snapshot.data['denticion'] ?? 0,
        estado = snapshot.data['estado'],
        diasEncierre = snapshot.data['diasEncierre'],
        empresaUuid = snapshot.data['empresaUuid'],
        origen = snapshot.data['origen'],
        propietario = snapshot.data['propietario'],
        empresaNombre = snapshot.data['empresaNombre'],
        categoriaUuid = snapshot.data['categoriaUuid'],
        categoriaNombre = snapshot.data['categoriaNombre'],
        puerta = snapshot.data['puerta'],
        tropaOrigen =
            snapshot.data['tropaOrigen'] ?? snapshot.data['tropaUuid'],
        corralOrigen =
            snapshot.data['corralOrigen'] ?? snapshot.data['corralUuid'],
        categoriaAnterior = snapshot.data['categoriaAnterior'] ??
            snapshot.data['categoriaUuid'],
        gdpv = snapshot.data['gdpv'].runtimeType == int
            ? double.parse(snapshot.data['gdpv'].toString())
            : snapshot.data['gdpv'],
        fechaUltimoEncierre = snapshot.data['fechaUltimoEncierre'] != null ? snapshot.data['fechaUltimoEncierre'].toDate() : null;

  Map<String, Object> toDocument() {
    return {
      'categoriaNombre': this.categoriaNombre,
      'categoriaUuid': this.categoriaUuid,
      'corralNombre': this.corralNombre,
      'corralUuid': this.corralUuid,
      'denticion': this.denticion,
      'diasEncierre': this.diasEncierre,
      'empresaNombre': this.empresaNombre,
      'empresaUuid': this.empresaUuid,
      'estado': this.estado,
      'fechaAlta': this.fechaAlta,
      'fechaUltPeso': this.fechaUltPeso,
      'idCuig': this.idCuig,
      'idElec': this.idElec,
      'idManejo': this.idManejo,
      'origen': this.origen,
      'propietario': this.propietario,
      'pesoAlta': this.pesoAlta,
      'pesoUlt': this.pesoUlt,
      'puerta': this.puerta,
      'sexo': this.sexo,
      'tropaNombre': this.tropaNombre,
      'tropaUuid': this.tropaUuid,
      'tropaOrigen': this.tropaOrigen,
      'corralOrigen': this.corralOrigen,
      'categoriaAnterior': this.categoriaAnterior,
      'gdpv': this.gdpv,
      'fechaUltimoEncierre' : this.fechaUltimoEncierre
    };
  }
}

==> 1.0.10.tar.gz: lib/src/entities/caravana_entity.dart <==
import 'package:equatable/equatable.dart';
import 'package:cloud_firestore/cloud_firestore.dart';

class CaravanaEntity extends Equatable {
  final String uuid;
  final String idManejo;
  final String idCuig;
  final String idElec;
  final String tropaUuid;
  final String tropaNombre;
  final String corralUuid;
  final String corralNombre;
  final DateTime fechaAlta;
  final double pesoAlta;
  final DateTime fechaUltPeso;
  final double pesoUlt;
  final bool sexo;
  final int denticion;
  final String estado;
  final int diasEncierre;
  final String empresaUuid;
  final String origen;
  final String propietario;
  final String empresaNombre;
  final String categoriaUuid;
  final String categoriaNombre;
  final int puerta;
  final String tropaOrigen;
  final String corralOrigen;
  final String categoriaAnterior;
  final double gdpv;
  final DateTime fechaUltimoEncierre;

  CaravanaEntity(
      this.uuid,
      this.idManejo,
      this.idCuig,
      this.idElec,
      this.tropaUuid,
      this.tropaNombre,
      this.corralUuid,
      this.corralNombre,
      this.fechaAlta,
      this.pesoAlta,
      this.fechaUltPeso,
      this.pesoUlt,
      this.sexo,
      this.denticion,
      this.estado,
      this.diasEncierre,
      this.empresaUuid,
      this.origen,
      this.propietario,
      this.empresaNombre,
      this.categoriaUuid,
      this.categoriaNombre,
      this.puerta,
      this.tropaOrigen,
      this.corralOrigen,
      this.categoriaAnterior,
      this.gdpv,
      this.fechaUltimoEncierre);

  Map<String, Object> toJson() {
    return {
      'categoriaNombre': this.categoriaNombre,
      'categoriaUuid': this.categoriaUuid,
      'corralNombre': this.corralNombre,
      'corralUuid': this.corralUuid,
      'denticion': this.denticion,
      'diasEncierre': this.diasEncierre,
      'empresaNombre': this.empresaNombre,
      'empresaUuid': this.empresaUuid,
      'estado': this.estado,
      'fechaAlta': this.fechaAlta,
      'fechaUltPeso': this.fechaUltPeso,
      'idCuig': this.idCuig,
      'idElec': this.idElec,
      'idManejo': this.idManejo,
      'origen': this.origen,
      'propietario': this.propietario,
      'pesoAlta': this.pesoAlta,
      'pesoUlt': this.pesoUlt,
      'puerta': this.puerta,
      'sexo': this.sexo,
      'tropaNombre': this.tropaNombre,
      'tropaUuid': this.tropaUuid,
      'tropaOrigen': this.tropaOrigen,
      'corralOrigen': this.corralOrigen,
      'categoriaAnterior': this.categoriaAnterior,
      'gdpv': this.gdpv,
      'fechaUltimoEncierre': this.fechaUltimoEncierre
    };
  }

  Map<String, dynamic> toMap() {
    return {
      'uuid': this.uuid,
      'categoriaNombre': this.categoriaNombre,
      'categoriaUuid': this.categoriaUuid,
      'corralNombre': this.corralNombre,
      'corralUuid': this.corralUuid,
      'denticion': this.denticion,
      'diasEncierre': this.diasEncierre,
      'empresaNombre': this.empresaNombre,
      'empresaUuid': this.empresaUuid,
      'estado': this.estado,
      'fechaAlta': this.fechaAlta,
      'fechaUltPeso': this.fechaUltPeso,
      'idCuig': this.idCuig,
      'idElec': this.idElec,
      'idManejo': this.idManejo,
      'origen': this.origen,
      'propietario': this.propietario,
      'pesoAlta': this.pesoAlta,
      'pesoUlt': this.pesoUlt,
      'puerta': this.puerta,
      'sexo': this.sexo,
      'tropaNombre': this.tropaNombre,
      'tropaUuid': this.tropaUuid,
      'tropaOrigen': this.tropaOrigen,
      'corralOrigen': this.corralOrigen,
      'categoriaAnterior': this.categoriaAnterior,
      'gdpv': this.gdpv,
      'fechaUltimoEncierre': this.fechaUltimoEncierre
    };
  }

  CaravanaEntity.fromMap(Map<dynamic, dynamic> data)
      : uuid = data['uuid'],
        idManejo = data['idManejo'],
        idCuig = data['idCuig'],
        idElec = data['idElec'],
        tropaUuid = data['tropaUuid'],
        tropaNombre = data['tropaNombre'],
        corralUuid = data['corralUuid'],
        corralNombre = data['corralNombre'],
        fechaAlta = data['fechaAlta'].runtimeType == DateTime
            ? data['fechaAlta']
            : data['fechaAlta'].toDate(),
        pesoAlta = double.parse(data['pesoAlta'].toString()),
        fechaUltPeso = data['fechaUltPeso'].runtimeType == DateTime
            ? data['fechaUltPeso']
            : data['fechaUltPeso'].toDate(),
        pesoUlt = double.parse(data['pesoUlt'].toString()),
        sexo = data['sexo'],
        denticion = data['denticion'],
        estado = data['estado'],
        diasEncierre = data['diasEncierre'],
        empresaUuid = data['empresaUuid'],
        origen = data['origen'],
        propietario = data['propietario'],
        empresaNombre = data['empresaNombre'],
        categoriaUuid = data['categoriaUuid'],
        categoriaNombre = data['categoriaNombre'],
        puerta = data['puerta'],
        tropaOrigen = data['tropaOrigen'] ?? data['tropaUuid'],
        corralOrigen = data['corralOrigen'] ?? data['corralUuid'],
        categoriaAnterior = data['categoriaAnterior'] ?? data['categoriaUuid'],
        gdpv = data['gdpv'],
        fechaUltimoEncierre = data['fechaUltimoEncierre'] == null ?  (data['fechaUltimoEncierre'] is Timestamp
            ? data['fechaUltimoEncierre'].toDate()
            : data['fechaUltimoEncierre']) : data['fechaAlta'];

  @override
  String toString() {
    return 'CaravanaEntity{uuid: $uuid, idManejo: $idManejo, idCuig: $idCuig, idElec: $idElec, tropaUuid: $tropaUuid, tropaNombre: $tropaNombre, corralUuid: $corralUuid, corralNombre: $corralNombre, fechaAlta: $fechaAlta, pesoAlta: $pesoAlta, fechaUltPeso: $fechaUltPeso, pesoUlt: $pesoUlt, sexo: $sexo, denticion: $denticion, estado: $estado, diasEncierre: $diasEncierre, empresaUuid: $empresaUuid, origen: $origen, propietario: $propietario, empresaNombre: $empresaNombre, categoriaUuid: $categoriaUuid, categoriaNombre: $categoriaNombre, puerta: $puerta, tropaOrigen: $tropaOrigen, corralOrigen: $corralOrigen, categoriaAnterior: $categoriaAnterior, gdpv: $gdpv, fechaUltimoEncierre: $fechaUltimoEncierre}';
  }

  CaravanaEntity.fromJson(Map<String, dynamic> data)
      : uuid = data['uuid'],
        idManejo = data['idManejo'],
        idCuig = data['idCuig'],
        idElec = data['idElec'],
        tropaUuid = data['tropaUuid'],
        tropaNombre = data['tropaNombre'],
        corralUuid = data['corralUuid'],
        corralNombre = data['corralNombre'],
        fechaAlta = data['fechaAlta'].toDate(),
        pesoAlta = double.parse(data['pesoAlta'].toString()),
        fechaUltPeso = data['fechaUltPeso'].toDate(),
        pesoUlt = double.parse(data['pesoUlt'].toString()),
        sexo = data['sexo'],
        denticion = data['denticion'],
        estado = data['estado'],
        diasEncierre = data['diasEncierre'],
        empresaUuid = data['empresaUuid'],
        origen = data['origen'],
        propietario = data['propietario'],
        empresaNombre = data['empresaNombre'],
        categoriaUuid = data['categoriaUuid'],
        categoriaNombre = data['categoriaNombre'],
        puerta = data['puerta'],
        tropaOrigen = data['tropaOrigen'],
        corralOrigen = data['corralOrigen'],
        categoriaAnterior = data['categoriaAnterior'],
        gdpv = data['gdpv'],
        fechaUltimoEncierre = data['fechaUltimoEncierre'];

  CaravanaEntity.fromSnapshot(DocumentSnapshot snapshot)
      : uuid = snapshot.documentID,
        idManejo = snapshot.data['idManejo'],
        idCuig = snapshot.data['idCuig'],
        idElec = snapshot.data['idElec'],
        tropaUuid = snapshot.data['tropaUuid'],
        tropaNombre = snapshot.data['tropaNombre'],
        corralUuid = snapshot.data['corralUuid'],
        corralNombre = snapshot.data['corralNombre'],
        fechaAlta = snapshot.data['fechaAlta'].toDate(),
        pesoAlta = double.parse(snapshot.data['pesoAlta'].toString()),
        fechaUltPeso = snapshot.data['fechaUltPeso'].toDate(),
        pesoUlt = double.parse(snapshot.data['pesoUlt'].toString()),
        sexo = snapshot.data['sexo'],
        denticion = snapshot.data['denticion'] ?? 0,
        estado = snapshot.data['estado'],
        diasEncierre = snapshot.data['diasEncierre'],
        empresaUuid = snapshot.data['empresaUuid'],
        origen = snapshot.data['origen'],
        propietario = snapshot.data['propietario'],
        empresaNombre = snapshot.data['empresaNombre'],
        categoriaUuid = snapshot.data['categoriaUuid'],
        categoriaNombre = snapshot.data['categoriaNombre'],
        puerta = snapshot.data['puerta'],
        tropaOrigen =
            snapshot.data['tropaOrigen'] ?? snapshot.data['tropaUuid'],
        corralOrigen =
            snapshot.data['corralOrigen'] ?? snapshot.data['corralUuid'],
        categoriaAnterior = snapshot.data['categoriaAnterior'] ??
            snapshot.data['categoriaUuid'],
        gdpv = snapshot.data['gdpv'].runtimeType == int
            ? double.parse(snapshot.data['gdpv'].toString())
            : snapshot.data['gdpv'],
        fechaUltimoEncierre = snapshot.data['fechaUltimoEncierre'] != null
            ? (snapshot.data['fechaUltimoEncierre'] is Timestamp
                ? snapshot.data['fechaUltimoEncierre'].toDate()
                : snapshot.data['fechaUltimoEncierre'])
            : snapshot.data['fechaAlta'].toDate();

  Map<String, Object> toDocument() {
    return {
      'categoriaNombre': this.categoriaNombre,
      'categoriaUuid': this.categoriaUuid,
      'corralNombre': this.corralNombre,
      'corralUuid': this.corralUuid,
      'denticion': this.denticion,
      'diasEncierre': this.diasEncierre,
      'empresaNombre': this.empresaNombre,
      'empresaUuid': this.empresaUuid,
      'estado': this.estado,
      'fechaAlta': this.fechaAlta,
      'fechaUltPeso': this.fechaUltPeso,
      'idCuig': this.idCuig,
      'idElec': this.idElec,
      'idManejo': this.idManejo,
      'origen': this.origen,
      'propietario': this.propietario,
      'pesoAlta': this.pesoAlta,
      'pesoUlt': this.pesoUlt,
      'puerta': this.puerta,
      'sexo': this.sexo,
      'tropaNombre': this.tropaNombre,
      'tropaUuid': this.tropaUuid,
      'tropaOrigen': this.tropaOrigen,
      'corralOrigen': this.corralOrigen,
      'categoriaAnterior': this.categoriaAnterior,
      'gdpv': this.gdpv,
      'fechaUltimoEncierre': this.fechaUltimoEncierre
    };
  }
}
